@@ -8,6 +8,8 @@
  * Authors:
  * - Muhammad Aditya Hilmy, <mhilmy@hey.com>, 2020
  */
+import { JupyterFrontEnd } from '@jupyterlab/application';
+import React from 'react';
 
 export const EXTENSION_ID = 'rucio-jupyterlab';
 export const METADATA_ATTACHMENTS_KEY = 'rucio_attachments';
@@ -18,3 +20,10 @@ export const searchByOptions = [
   { title: 'Datasets or Containers', value: 'datasets' },
   { title: 'Files', value: 'files' }
 ];
+
+export namespace CommandIDs {
+  export const UploadFile = `${EXTENSION_ID}:upload-file`;
+  export const OpenUploadLog = `${EXTENSION_ID}:open-upload-log`;
+}
+
+export const JupyterLabAppContext = React.createContext<JupyterFrontEnd | undefined>(undefined);
